@@ -29,6 +29,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include "html.h"
+#include "auction.h"
 #include "auctioninfo.h"
 #include "history.h"
 #include "esniper.h"
@@ -54,14 +55,14 @@ static const char PRIVATE[] = "private auction - bidders' identities protected";
  *	1 error (badly formatted page, etc) - sets auctionError
  */
 int
-parseBidHistory(memBuf_t *mp, auctionInfo *aip, time_t start, time_t *timeToFirstByte)
+parseBidHistory(memBuf_t *mp, auctionInfo *aip, time_t start, time_t *timeToFirstByte, int debugMode)
 {
 	char *line;
 	char **row = NULL;
 	int rowCount;
 	int ret = 0;		/* 0 = OK, 1 = failed */
 	int foundHeader = 0;	/* found bid history table header */
-	char *pagename;
+	pageInfo_t *pp;
 	int pageType;
 	int got;
 
@@ -70,27 +71,34 @@ parseBidHistory(memBuf_t *mp, auctionInfo *aip, time_t start, time_t *timeToFirs
 	if (timeToFirstByte)
 		*timeToFirstByte = getTimeToFirstByte(mp);
 
-	pagename = getPageName(mp);
-	if (!strncmp(pagename, "PageViewBids", 12)) {
-		pageType = VIEWBIDS;
-		/* bid history or expired/bad auction number */
-		while ((line = getNonTag(mp))) {
-			if (!strcmp(line, "Bid History")) {
-				log(("parseBidHistory(): got \"Bid History\"\n"));
-				break;
-			}
-			if (!strcmp(line, "Unknown Item")) {
-				log(("parseBidHistory(): got \"Unknown Item\"\n"));
-				return auctionError(aip, ae_baditem, NULL);
+	if (pp = getPageInfo(mp)) {
+		if (pp->srcId && !strcmp(pp->srcId, "Captcha.xsl"))
+			return auctionError(aip, ae_captcha, NULL);
+		if (pp->pageName && !strncmp(pp->pageName, "PageViewBids", 12)) {
+			pageType = VIEWBIDS;
+			/* bid history or expired/bad auction number */
+			while ((line = getNonTag(mp))) {
+				if (!strcmp(line, "Bid History")) {
+					log(("parseBidHistory(): got \"Bid History\"\n"));
+					break;
+				}
+				if (!strcmp(line, "Unknown Item")) {
+					log(("parseBidHistory(): got \"Unknown Item\"\n"));
+					return auctionError(aip, ae_baditem, NULL);
+				}
 			}
+		} else if (pp->pageName && !strncmp(pp->pageName, "PageViewTransactions", 20)) {
+			/* transaction history -- buy it now only */
+			pageType = VIEWTRANSACTIONS;
+		} else if (pp->pageName && !strcmp(pp->pageName, "PageSignIn")) {
+			return auctionError(aip, ae_mustsignin, NULL);
+		} else {
+			bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, "unknown pagename");
+			return auctionError(aip, ae_notitle, NULL);
 		}
-	} else if (!strncmp(pagename, "PageViewTransactions", 20)) {
-		/* transaction history -- buy it now only */
-		pageType = VIEWTRANSACTIONS;
-	} else if (!strcmp(pagename, "PageSignIn")) {
-		return auctionError(aip, ae_mustsignin, NULL);
 	} else {
-		bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, "unknown pagename");
+		log(("parseBidHistory(): pageinfo is NULL\n"));
+		bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, "pageInfo is NULL");
 		return auctionError(aip, ae_notitle, NULL);
 	}
 
@@ -111,16 +119,16 @@ parseBidHistory(memBuf_t *mp, auctionInfo *aip, time_t start, time_t *timeToFirs
 		bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, "no item number");
 		return auctionError(aip, ae_baditem, NULL);
 	}
-#if DEBUG
-	free(aip->auction);
-	aip->auction = myStrdup(line);
-#else
-	if (strcmp(aip->auction, line)) {
-		log(("parseBidHistory(): auction number %s does not match given number %s", line, aip->auction));
-		bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, "mismatched item number");
-		return auctionError(aip, ae_baditem, NULL);
+	if (debugMode) {
+		free(aip->auction);
+		aip->auction = myStrdup(line);
+	} else {
+		if (strcmp(aip->auction, line)) {
+			log(("parseBidHistory(): auction number %s does not match given number %s", line, aip->auction));
+			bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, "mismatched item number");
+			return auctionError(aip, ae_baditem, NULL);
+		}
 	}
-#endif
 
 	/* Auction title */
 	memReset(mp);
@@ -195,11 +203,14 @@ parseBidHistory(memBuf_t *mp, auctionInfo *aip, time_t start, time_t *timeToFirs
 				return auctionError(aip, ae_noquantity, NULL);
 			}
 			errno = 0;
-			aip->quantity = (int)strtol(line, NULL, 10);
-			if (aip->quantity < 0 || (aip->quantity == 0 && errno == EINVAL)) {
-				bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, "item quantity could not be converted");
-				return auctionError(aip, ae_noquantity, NULL);
-			}
+			if (isdigit(*line)) {
+				aip->quantity = (int)strtol(line, NULL, 10);
+				if (aip->quantity < 0 || (aip->quantity == 0 && errno == EINVAL)) {
+					bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, "item quantity could not be converted");
+					return auctionError(aip, ae_noquantity, NULL);
+				}
+			} else
+				aip->quantity = 1;
 			log(("quantity: %d", aip->quantity));
 			got |= QUANTITY;
 		} else if (!strcasecmp(line, "Shipping:")) {
@@ -255,9 +266,8 @@ parseBidHistory(memBuf_t *mp, auctionInfo *aip, time_t start, time_t *timeToFirs
 		/* formated time/date output */
 		tmPtr = localtime(&(aip->endTime));
 		strftime(timestr , 20, "%d/%m/%Y %H:%M:%S", tmPtr);
-#if !DEBUG
-		printLog(stdout, "End time: %s\n", timestr);
-#endif
+		if (!debugMode)
+			printLog(stdout, "End time: %s\n", timestr);
 	} else
 		aip->endTime = aip->remain;
 
